@@ -174,36 +174,20 @@ class SourceCredibilityAnalysis(object):
                                   'sports': 3,
                                   'health': 4,
                                   'general': 4,
-                                  'business': 4}
-        return category_mapping
-
-    @staticmethod
-    def get_alternative_category_mapping() -> dict:
-        category_mapping: dict = {'Agriculture': 4,
-                                  'Business': 4,
-                                  'Entertainment': 3,
-                                  'Ethnic': 3,
-                                  'Sport': 3,
-                                  'General Interest': 4,
-                                  'Government': 5,
-                                  'Religion': 2,
-                                  'Satire': 1,
-                                  'Alternative': 3,
-                                  'Science Tech': 5,
-                                  'Shopper': 2,
-                                  'Military': 4}
+                                  'business': 4,
+                                  'religion': 2,
+                                  'ethnic': 3,
+                                  'military': 4,
+                                  'satire': 1,
+                                  'government': 5,
+                                  'alternative': 3}
         return category_mapping
 
     def get_importance_from_category(self, category_key: str) -> float:
         importance: float = 1.0
         try:
             category_mapping: dict = self.get_category_mapping()
-            importance: float = category_mapping.get(category_key, -1)
-
-            # Alternative categories
-            if importance == -1:
-                category_mapping: dict = self.get_alternative_category_mapping()
-                importance: float = category_mapping.get(category_key, 1)
+            importance: float = category_mapping.get(category_key, 1)
 
         except Exception as e:
             logger.error(e)
@@ -313,7 +297,7 @@ class SourceCredibilityAnalysis(object):
 
             user_data: dict = self.twitter_connector.retrieve_user_data(
                 user=user)
-            print(user_data)
+
             # 3. Retrieve analysis
             twitter_credibility: TwitterCredibilityDoc = self.analyse_account_by_id(
                 user_id=user_data.get("id"))
