@@ -85,7 +85,7 @@ def compute_importance_from_exponential_distribution(x, alpha: int = 0.6) -> flo
     return importance
 
 
-def get_datetime_from_str(str_datetime: str, target_format: str = '%Y-%m-%d %H:%M:%S') -> datetime:
+def get_datetime_from_str(str_datetime: str, target_format: str = '%Y/%m/%d %H:%M:%S') -> datetime:
 
     origin_datetime_obj: datetime = parse(str_datetime)
     target_datetime_obj: datetime = datetime.strptime(
@@ -95,8 +95,8 @@ def get_datetime_from_str(str_datetime: str, target_format: str = '%Y-%m-%d %H:%
 
 
 def get_str_datetime_from_non_formatted_str(str_datetime: str,
-                                            target_format: str = '%Y-%m-%d %H:%M:%S') -> str:
-    target_datetime_obj: str = "1996-01-01 00:00:00"
+                                            target_format: str = '%Y/%m/%d %H:%M:%S') -> str:
+    target_datetime_obj: str = "1996/01/01 00:00:00"
     try:
         if len(str_datetime) > 1:
             origin_datetime_obj: datetime = parse(str_datetime)
@@ -264,7 +264,7 @@ def load_resources_from_csv(resources_dir: str, filename:str) -> pd.DataFrame:
         resource: str = os.path.join(resources_dir, filename)
         full_path: str = get_data_smart(
             package="sourceRank", resource=resource, as_string=False)
-        print(full_path)
+        logger.info(f"Loading media information from static file allocated at: {full_path}")
         df_resources: pd.DataFrame = pd.read_csv(full_path, index_col=0)
     except Exception as e:
         logger.error(e)
